
'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/kernels/boosted_trees/boosted_trees.proto', package='tensorflow.boosted_trees', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x12BoostedTreesProtosP\x01\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n9tensorflow/core/kernels/boosted_trees/boosted_trees.proto\x12\x18tensorflow.boosted_trees"\xc6\x02\n\x04Node\x12.\n\x04leaf\x18\x01 \x01(\x0b2\x1e.tensorflow.boosted_trees.LeafH\x00\x12E\n\x10bucketized_split\x18\x02 \x01(\x0b2).tensorflow.boosted_trees.BucketizedSplitH\x00\x12G\n\x11categorical_split\x18\x03 \x01(\x0b2*.tensorflow.boosted_trees.CategoricalSplitH\x00\x12;\n\x0bdense_split\x18\x04 \x01(\x0b2$.tensorflow.boosted_trees.DenseSplitH\x00\x129\n\x08metadata\x18\x89\x06 \x01(\x0b2&.tensorflow.boosted_trees.NodeMetadataB\x06\n\x04node"S\n\x0cNodeMetadata\x12\x0c\n\x04gain\x18\x01 \x01(\x02\x125\n\roriginal_leaf\x18\x02 \x01(\x0b2\x1e.tensorflow.boosted_trees.Leaf"\x93\x01\n\x04Leaf\x122\n\x06vector\x18\x01 \x01(\x0b2 .tensorflow.boosted_trees.VectorH\x00\x12?\n\rsparse_vector\x18\x02 \x01(\x0b2&.tensorflow.boosted_trees.SparseVectorH\x00\x12\x0e\n\x06scalar\x18\x03 \x01(\x02B\x06\n\x04leaf"\x17\n\x06Vector\x12\r\n\x05value\x18\x01 \x03(\x02",\n\x0cSparseVector\x12\r\n\x05index\x18\x01 \x03(\x05\x12\r\n\x05value\x18\x02 \x03(\x02"\xb8\x01\n\x0fBucketizedSplit\x12\x12\n\nfeature_id\x18\x01 \x01(\x05\x12\x11\n\tthreshold\x18\x02 \x01(\x05\x12\x14\n\x0cdimension_id\x18\x05 \x01(\x05\x12E\n\x11default_direction\x18\x06 \x01(\x0e2*.tensorflow.boosted_trees.DefaultDirection\x12\x0f\n\x07left_id\x18\x03 \x01(\x05\x12\x10\n\x08right_id\x18\x04 \x01(\x05"n\n\x10CategoricalSplit\x12\x12\n\nfeature_id\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05\x12\x14\n\x0cdimension_id\x18\x05 \x01(\x05\x12\x0f\n\x07left_id\x18\x03 \x01(\x05\x12\x10\n\x08right_id\x18\x04 \x01(\x05"V\n\nDenseSplit\x12\x12\n\nfeature_id\x18\x01 \x01(\x05\x12\x11\n\tthreshold\x18\x02 \x01(\x02\x12\x0f\n\x07left_id\x18\x03 \x01(\x05\x12\x10\n\x08right_id\x18\x04 \x01(\x05"5\n\x04Tree\x12-\n\x05nodes\x18\x01 \x03(\x0b2\x1e.tensorflow.boosted_trees.Node"\xdc\x01\n\x0cTreeMetadata\x12\x18\n\x10num_layers_grown\x18\x02 \x01(\x05\x12\x14\n\x0cis_finalized\x18\x03 \x01(\x08\x12Z\n\x16post_pruned_nodes_meta\x18\x04 \x03(\x0b2:.tensorflow.boosted_trees.TreeMetadata.PostPruneNodeUpdate\x1a@\n\x13PostPruneNodeUpdate\x12\x13\n\x0bnew_node_id\x18\x01 \x01(\x05\x12\x14\n\x0clogit_change\x18\x02 \x03(\x02"\x88\x01\n\x0fGrowingMetadata\x12\x1b\n\x13num_trees_attempted\x18\x01 \x01(\x03\x12\x1c\n\x14num_layers_attempted\x18\x02 \x01(\x03\x12\x1d\n\x15last_layer_node_start\x18\x03 \x01(\x05\x12\x1b\n\x13last_layer_node_end\x18\x04 \x01(\x05"\xd7\x01\n\x0cTreeEnsemble\x12-\n\x05trees\x18\x01 \x03(\x0b2\x1e.tensorflow.boosted_trees.Tree\x12\x14\n\x0ctree_weights\x18\x02 \x03(\x02\x12=\n\rtree_metadata\x18\x03 \x03(\x0b2&.tensorflow.boosted_trees.TreeMetadata\x12C\n\x10growing_metadata\x18\x04 \x01(\x0b2).tensorflow.boosted_trees.GrowingMetadata"N\n\x0bDebugOutput\x12\x13\n\x0bfeature_ids\x18\x01 \x03(\x05\x12\x13\n\x0blogits_path\x18\x02 \x03(\x02\x12\x15\n\rleaf_node_ids\x18\x03 \x03(\x05*m\n\x14SplitTypeWithDefault\x12\x1b\n\x17INEQUALITY_DEFAULT_LEFT\x10\x00\x12\x1c\n\x18INEQUALITY_DEFAULT_RIGHT\x10\x01\x12\x1a\n\x16EQUALITY_DEFAULT_RIGHT\x10\x03*7\n\x10DefaultDirection\x12\x10\n\x0cDEFAULT_LEFT\x10\x00\x12\x11\n\rDEFAULT_RIGHT\x10\x01B3\n\x18org.tensorflow.frameworkB\x12BoostedTreesProtosP\x01\xf8\x01\x01b\x06proto3')
_SPLITTYPEWITHDEFAULT = _descriptor.EnumDescriptor(name='SplitTypeWithDefault', full_name='tensorflow.boosted_trees.SplitTypeWithDefault', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INEQUALITY_DEFAULT_LEFT', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='INEQUALITY_DEFAULT_RIGHT', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='EQUALITY_DEFAULT_RIGHT', index=2, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1824, serialized_end=1933)
_sym_db.RegisterEnumDescriptor(_SPLITTYPEWITHDEFAULT)
SplitTypeWithDefault = enum_type_wrapper.EnumTypeWrapper(_SPLITTYPEWITHDEFAULT)
_DEFAULTDIRECTION = _descriptor.EnumDescriptor(name='DefaultDirection', full_name='tensorflow.boosted_trees.DefaultDirection', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='DEFAULT_LEFT', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DEFAULT_RIGHT', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1935, serialized_end=1990)
_sym_db.RegisterEnumDescriptor(_DEFAULTDIRECTION)
DefaultDirection = enum_type_wrapper.EnumTypeWrapper(_DEFAULTDIRECTION)
INEQUALITY_DEFAULT_LEFT = 0
INEQUALITY_DEFAULT_RIGHT = 1
EQUALITY_DEFAULT_RIGHT = 3
DEFAULT_LEFT = 0
DEFAULT_RIGHT = 1
_NODE = _descriptor.Descriptor(name='Node', full_name='tensorflow.boosted_trees.Node', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='leaf', full_name='tensorflow.boosted_trees.Node.leaf', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bucketized_split', full_name='tensorflow.boosted_trees.Node.bucketized_split', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='categorical_split', full_name='tensorflow.boosted_trees.Node.categorical_split', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dense_split', full_name='tensorflow.boosted_trees.Node.dense_split', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.boosted_trees.Node.metadata', index=4, number=777, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='node', full_name='tensorflow.boosted_trees.Node.node', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=88, serialized_end=414)
_NODEMETADATA = _descriptor.Descriptor(name='NodeMetadata', full_name='tensorflow.boosted_trees.NodeMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='gain', full_name='tensorflow.boosted_trees.NodeMetadata.gain', index=0, number=1, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='original_leaf', full_name='tensorflow.boosted_trees.NodeMetadata.original_leaf', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=416, serialized_end=499)
_LEAF = _descriptor.Descriptor(name='Leaf', full_name='tensorflow.boosted_trees.Leaf', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='vector', full_name='tensorflow.boosted_trees.Leaf.vector', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='sparse_vector', full_name='tensorflow.boosted_trees.Leaf.sparse_vector', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='scalar', full_name='tensorflow.boosted_trees.Leaf.scalar', index=2, number=3, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='leaf', full_name='tensorflow.boosted_trees.Leaf.leaf', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=502, serialized_end=649)
_VECTOR = _descriptor.Descriptor(name='Vector', full_name='tensorflow.boosted_trees.Vector', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='value', full_name='tensorflow.boosted_trees.Vector.value', index=0, number=1, type=2, cpp_type=6, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=651, serialized_end=674)
_SPARSEVECTOR = _descriptor.Descriptor(name='SparseVector', full_name='tensorflow.boosted_trees.SparseVector', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='index', full_name='tensorflow.boosted_trees.SparseVector.index', index=0, number=1, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.boosted_trees.SparseVector.value', index=1, number=2, type=2, cpp_type=6, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=676, serialized_end=720)
_BUCKETIZEDSPLIT = _descriptor.Descriptor(name='BucketizedSplit', full_name='tensorflow.boosted_trees.BucketizedSplit', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='feature_id', full_name='tensorflow.boosted_trees.BucketizedSplit.feature_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='threshold', full_name='tensorflow.boosted_trees.BucketizedSplit.threshold', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dimension_id', full_name='tensorflow.boosted_trees.BucketizedSplit.dimension_id', index=2, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='default_direction', full_name='tensorflow.boosted_trees.BucketizedSplit.default_direction', index=3, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='left_id', full_name='tensorflow.boosted_trees.BucketizedSplit.left_id', index=4, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='right_id', full_name='tensorflow.boosted_trees.BucketizedSplit.right_id', index=5, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=723, serialized_end=907)
_CATEGORICALSPLIT = _descriptor.Descriptor(name='CategoricalSplit', full_name='tensorflow.boosted_trees.CategoricalSplit', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='feature_id', full_name='tensorflow.boosted_trees.CategoricalSplit.feature_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.boosted_trees.CategoricalSplit.value', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dimension_id', full_name='tensorflow.boosted_trees.CategoricalSplit.dimension_id', index=2, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='left_id', full_name='tensorflow.boosted_trees.CategoricalSplit.left_id', index=3, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='right_id', full_name='tensorflow.boosted_trees.CategoricalSplit.right_id', index=4, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=909, serialized_end=1019)
_DENSESPLIT = _descriptor.Descriptor(name='DenseSplit', full_name='tensorflow.boosted_trees.DenseSplit', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='feature_id', full_name='tensorflow.boosted_trees.DenseSplit.feature_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='threshold', full_name='tensorflow.boosted_trees.DenseSplit.threshold', index=1, number=2, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='left_id', full_name='tensorflow.boosted_trees.DenseSplit.left_id', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='right_id', full_name='tensorflow.boosted_trees.DenseSplit.right_id', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1021, serialized_end=1107)
_TREE = _descriptor.Descriptor(name='Tree', full_name='tensorflow.boosted_trees.Tree', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='nodes', full_name='tensorflow.boosted_trees.Tree.nodes', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1109, serialized_end=1162)
_TREEMETADATA_POSTPRUNENODEUPDATE = _descriptor.Descriptor(name='PostPruneNodeUpdate', full_name='tensorflow.boosted_trees.TreeMetadata.PostPruneNodeUpdate', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='new_node_id', full_name='tensorflow.boosted_trees.TreeMetadata.PostPruneNodeUpdate.new_node_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='logit_change', full_name='tensorflow.boosted_trees.TreeMetadata.PostPruneNodeUpdate.logit_change', index=1, number=2, type=2, cpp_type=6, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1321, serialized_end=1385)
_TREEMETADATA = _descriptor.Descriptor(name='TreeMetadata', full_name='tensorflow.boosted_trees.TreeMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_layers_grown', full_name='tensorflow.boosted_trees.TreeMetadata.num_layers_grown', index=0, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_finalized', full_name='tensorflow.boosted_trees.TreeMetadata.is_finalized', index=1, number=3, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='post_pruned_nodes_meta', full_name='tensorflow.boosted_trees.TreeMetadata.post_pruned_nodes_meta', index=2, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TREEMETADATA_POSTPRUNENODEUPDATE], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1165, serialized_end=1385)
_GROWINGMETADATA = _descriptor.Descriptor(name='GrowingMetadata', full_name='tensorflow.boosted_trees.GrowingMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_trees_attempted', full_name='tensorflow.boosted_trees.GrowingMetadata.num_trees_attempted', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_layers_attempted', full_name='tensorflow.boosted_trees.GrowingMetadata.num_layers_attempted', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='last_layer_node_start', full_name='tensorflow.boosted_trees.GrowingMetadata.last_layer_node_start', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='last_layer_node_end', full_name='tensorflow.boosted_trees.GrowingMetadata.last_layer_node_end', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1388, serialized_end=1524)
_TREEENSEMBLE = _descriptor.Descriptor(name='TreeEnsemble', full_name='tensorflow.boosted_trees.TreeEnsemble', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='trees', full_name='tensorflow.boosted_trees.TreeEnsemble.trees', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tree_weights', full_name='tensorflow.boosted_trees.TreeEnsemble.tree_weights', index=1, number=2, type=2, cpp_type=6, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tree_metadata', full_name='tensorflow.boosted_trees.TreeEnsemble.tree_metadata', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='growing_metadata', full_name='tensorflow.boosted_trees.TreeEnsemble.growing_metadata', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1527, serialized_end=1742)
_DEBUGOUTPUT = _descriptor.Descriptor(name='DebugOutput', full_name='tensorflow.boosted_trees.DebugOutput', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='feature_ids', full_name='tensorflow.boosted_trees.DebugOutput.feature_ids', index=0, number=1, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='logits_path', full_name='tensorflow.boosted_trees.DebugOutput.logits_path', index=1, number=2, type=2, cpp_type=6, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='leaf_node_ids', full_name='tensorflow.boosted_trees.DebugOutput.leaf_node_ids', index=2, number=3, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1744, serialized_end=1822)
_NODE.fields_by_name['leaf'].message_type = _LEAF
_NODE.fields_by_name['bucketized_split'].message_type = _BUCKETIZEDSPLIT
_NODE.fields_by_name['categorical_split'].message_type = _CATEGORICALSPLIT
_NODE.fields_by_name['dense_split'].message_type = _DENSESPLIT
_NODE.fields_by_name['metadata'].message_type = _NODEMETADATA
_NODE.oneofs_by_name['node'].fields.append(_NODE.fields_by_name['leaf'])
_NODE.fields_by_name['leaf'].containing_oneof = _NODE.oneofs_by_name['node']
_NODE.oneofs_by_name['node'].fields.append(_NODE.fields_by_name['bucketized_split'])
_NODE.fields_by_name['bucketized_split'].containing_oneof = _NODE.oneofs_by_name['node']
_NODE.oneofs_by_name['node'].fields.append(_NODE.fields_by_name['categorical_split'])
_NODE.fields_by_name['categorical_split'].containing_oneof = _NODE.oneofs_by_name['node']
_NODE.oneofs_by_name['node'].fields.append(_NODE.fields_by_name['dense_split'])
_NODE.fields_by_name['dense_split'].containing_oneof = _NODE.oneofs_by_name['node']
_NODEMETADATA.fields_by_name['original_leaf'].message_type = _LEAF
_LEAF.fields_by_name['vector'].message_type = _VECTOR
_LEAF.fields_by_name['sparse_vector'].message_type = _SPARSEVECTOR
_LEAF.oneofs_by_name['leaf'].fields.append(_LEAF.fields_by_name['vector'])
_LEAF.fields_by_name['vector'].containing_oneof = _LEAF.oneofs_by_name['leaf']
_LEAF.oneofs_by_name['leaf'].fields.append(_LEAF.fields_by_name['sparse_vector'])
_LEAF.fields_by_name['sparse_vector'].containing_oneof = _LEAF.oneofs_by_name['leaf']
_BUCKETIZEDSPLIT.fields_by_name['default_direction'].enum_type = _DEFAULTDIRECTION
_TREE.fields_by_name['nodes'].message_type = _NODE
_TREEMETADATA_POSTPRUNENODEUPDATE.containing_type = _TREEMETADATA
_TREEMETADATA.fields_by_name['post_pruned_nodes_meta'].message_type = _TREEMETADATA_POSTPRUNENODEUPDATE
_TREEENSEMBLE.fields_by_name['trees'].message_type = _TREE
_TREEENSEMBLE.fields_by_name['tree_metadata'].message_type = _TREEMETADATA
_TREEENSEMBLE.fields_by_name['growing_metadata'].message_type = _GROWINGMETADATA
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['NodeMetadata'] = _NODEMETADATA
DESCRIPTOR.message_types_by_name['Leaf'] = _LEAF
DESCRIPTOR.message_types_by_name['Vector'] = _VECTOR
DESCRIPTOR.message_types_by_name['SparseVector'] = _SPARSEVECTOR
DESCRIPTOR.message_types_by_name['BucketizedSplit'] = _BUCKETIZEDSPLIT
DESCRIPTOR.message_types_by_name['CategoricalSplit'] = _CATEGORICALSPLIT
DESCRIPTOR.message_types_by_name['DenseSplit'] = _DENSESPLIT
DESCRIPTOR.message_types_by_name['Tree'] = _TREE
DESCRIPTOR.message_types_by_name['TreeMetadata'] = _TREEMETADATA
DESCRIPTOR.message_types_by_name['GrowingMetadata'] = _GROWINGMETADATA
DESCRIPTOR.message_types_by_name['TreeEnsemble'] = _TREEENSEMBLE
DESCRIPTOR.message_types_by_name['DebugOutput'] = _DEBUGOUTPUT
DESCRIPTOR.enum_types_by_name['SplitTypeWithDefault'] = _SPLITTYPEWITHDEFAULT
DESCRIPTOR.enum_types_by_name['DefaultDirection'] = _DEFAULTDIRECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {'DESCRIPTOR': _NODE, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(Node)
NodeMetadata = _reflection.GeneratedProtocolMessageType('NodeMetadata', (_message.Message,), {'DESCRIPTOR': _NODEMETADATA, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(NodeMetadata)
Leaf = _reflection.GeneratedProtocolMessageType('Leaf', (_message.Message,), {'DESCRIPTOR': _LEAF, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(Leaf)
Vector = _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {'DESCRIPTOR': _VECTOR, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(Vector)
SparseVector = _reflection.GeneratedProtocolMessageType('SparseVector', (_message.Message,), {'DESCRIPTOR': _SPARSEVECTOR, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(SparseVector)
BucketizedSplit = _reflection.GeneratedProtocolMessageType('BucketizedSplit', (_message.Message,), {'DESCRIPTOR': _BUCKETIZEDSPLIT, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(BucketizedSplit)
CategoricalSplit = _reflection.GeneratedProtocolMessageType('CategoricalSplit', (_message.Message,), {'DESCRIPTOR': _CATEGORICALSPLIT, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(CategoricalSplit)
DenseSplit = _reflection.GeneratedProtocolMessageType('DenseSplit', (_message.Message,), {'DESCRIPTOR': _DENSESPLIT, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(DenseSplit)
Tree = _reflection.GeneratedProtocolMessageType('Tree', (_message.Message,), {'DESCRIPTOR': _TREE, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(Tree)
TreeMetadata = _reflection.GeneratedProtocolMessageType('TreeMetadata', (_message.Message,), {'PostPruneNodeUpdate': _reflection.GeneratedProtocolMessageType('PostPruneNodeUpdate', (_message.Message,), {'DESCRIPTOR': _TREEMETADATA_POSTPRUNENODEUPDATE, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'}), 'DESCRIPTOR': _TREEMETADATA, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(TreeMetadata)
_sym_db.RegisterMessage(TreeMetadata.PostPruneNodeUpdate)
GrowingMetadata = _reflection.GeneratedProtocolMessageType('GrowingMetadata', (_message.Message,), {'DESCRIPTOR': _GROWINGMETADATA, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(GrowingMetadata)
TreeEnsemble = _reflection.GeneratedProtocolMessageType('TreeEnsemble', (_message.Message,), {'DESCRIPTOR': _TREEENSEMBLE, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(TreeEnsemble)
DebugOutput = _reflection.GeneratedProtocolMessageType('DebugOutput', (_message.Message,), {'DESCRIPTOR': _DEBUGOUTPUT, '__module__': 'tensorflow.core.kernels.boosted_trees.boosted_trees_pb2'})
_sym_db.RegisterMessage(DebugOutput)
DESCRIPTOR._options = None



from . import core

def consume_prefix(s: core.StringPiece, expected) -> bool:
  ex = core.string_view(expected)
  if not s.slice().startswith(ex.slice()):
    return False
  s.remove_prefix(ex.size())
  return True




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/python/training/checkpoint_state.proto', package='tensorflow', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n1tensorflow/python/training/checkpoint_state.proto\x12\ntensorflow"\x9f\x01\n\x0fCheckpointState\x12\x1d\n\x15model_checkpoint_path\x18\x01 \x01(\t\x12"\n\x1aall_model_checkpoint_paths\x18\x02 \x03(\t\x12\'\n\x1fall_model_checkpoint_timestamps\x18\x03 \x03(\x01\x12 \n\x18last_preserved_timestamp\x18\x04 \x01(\x01B\x03\xf8\x01\x01b\x06proto3')
_CHECKPOINTSTATE = _descriptor.Descriptor(name='CheckpointState', full_name='tensorflow.CheckpointState', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='model_checkpoint_path', full_name='tensorflow.CheckpointState.model_checkpoint_path', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_model_checkpoint_paths', full_name='tensorflow.CheckpointState.all_model_checkpoint_paths', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_model_checkpoint_timestamps', full_name='tensorflow.CheckpointState.all_model_checkpoint_timestamps', index=2, number=3, type=1, cpp_type=5, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='last_preserved_timestamp', full_name='tensorflow.CheckpointState.last_preserved_timestamp', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=66, serialized_end=225)
DESCRIPTOR.message_types_by_name['CheckpointState'] = _CHECKPOINTSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CheckpointState = _reflection.GeneratedProtocolMessageType('CheckpointState', (_message.Message,), {'DESCRIPTOR': _CHECKPOINTSTATE, '__module__': 'tensorflow.python.training.checkpoint_state_pb2'})
_sym_db.RegisterMessage(CheckpointState)
DESCRIPTOR._options = None



from . import table
from . import env
from . import core
from . import errors
from . import naming
from . import tensor
from . import tensor_shape
from . import file_system
from . import file_system_helper
from .tensorflow.python.platform import tf_logging as logging
from .pb.tensorflow.core.protobuf import tensor_bundle_pb2
from .pb.tensorflow.core.framework import types_pb2

from typing import Tuple, Optional, List
import time
import sys

import numpy as np
import mmap

class BundleReader:
  _data: List[Optional[file_system.RandomAccessFile]]
  _mmap: List[Optional[mmap.mmap]]

  def __init__(self, env_: env.Env, prefix):
    self._prefix = core.string_view(prefix).bytes()
    self._env = env_
    filename = naming.meta_filename(self._prefix)
    file_size = errors.raise_if_error(env_.get_file_size(filename))
    self._metadata = errors.raise_if_error(env_.new_random_access_file(filename))
    self._table = table.Table.open(self._metadata, file_size)
    iter = self._table._rep.index_block.new_iterator()
    iter.seek_to_first()
    #proto = tensor_bundle_pb2.BundleHeaderProto()
    #proto.ParseFromString(iter._value._data[iter._value.offset + iter._value.size:])
    handle = table.BlockHandle()
    handle.decode_from(iter.value())
    zz = table.Block(table.read_block(self._metadata, handle))
    iter2 = zz.new_iterator()
    iter2.seek_to_first()
    header = tensor_bundle_pb2.BundleHeaderProto()
    header.ParseFromString(iter2.value().bytes())
    iter2.next()
    self._data = [None for _ in range(header.num_shards)]
    self._mmap = [None for _ in range(header.num_shards)]
    self._entries = []
    self._tensors = []
    self._num_shards = header.num_shards
    now = time.time()
    while iter2.valid():
      key = iter2.key().bytes()
      # print(key)
      val = tensor_bundle_pb2.BundleEntryProto()
      val.ParseFromString(iter2.value().bytes())
      self._entries.append((key, val))
      # arr = errors.raise_if_error(self.get_value(val)).to_py()
      arr = errors.raise_if_error(self.get_numpy(val))
      self._tensors.append((key, arr))
      # print(key, arr.shape)
      # print(arr.reshape((-1,))[0])
      # print(arr)
      # print(arr.sum(axis=-1))
      iter2.next()
    # file_system_helper.for_each(0, len(self._tensors), lambda i: print(self._env.get_current_thread_id(), self._tensors[i][0], self._tensors[i][1].sum()))
    elapsed = time.time() - now
    logging.info('Read %s in %0.2f msec', self._prefix, (elapsed * 1000.0))

  def get_file(self, entry: tensor_bundle_pb2.BundleEntryProto) -> Tuple[errors.Status, Optional[file_system.RandomAccessFile]]:
    # Open the data file if it has not been opened.
    file = self._data[entry.shard_id]
    if file is None:
      s, file = self._env.new_random_access_file(naming.data_filename(self._prefix, entry.shard_id, self._num_shards))
      if not s.ok():
        return s, None
      self._data[entry.shard_id] = file
      fileno = getattr(file, '_fd', None)
      if fileno is not None:
        # bytes = entry.offset + entry.size
        # offset = entry.offset
        # start = offset - offset % mmap.ALLOCATIONGRANULARITY
        # bytes -= start
        # array_offset = offset - start
        bytes = 0
        start = 0
        mm = mmap.mmap(fileno, bytes, access=mmap.ACCESS_READ, offset=start)
        self._mmap[entry.shard_id] = mm
    assert file is not None
    return errors.Status.OK(), file

  def get_mmap(self, entry: tensor_bundle_pb2.BundleEntryProto) -> Tuple[errors.Status, Optional[mmap.mmap]]:
    mm = self._mmap[entry.shard_id]
    if mm is None:
      s, file = self.get_file(entry)
      if not s.ok():
        return s, None
      fileno = getattr(file, '_fd', None)
      if fileno is not None:
        bytes = 0
        start = 0
        mm = mmap.mmap(fileno, bytes, access=mmap.ACCESS_READ, offset=start)
        self._mmap[entry.shard_id] = mm
    if mm is None:
      return errors.Unavailable("Can't mmap file"), None
    else:
      return errors.Status.OK(), mm

  def get_value(self, entry: tensor_bundle_pb2.BundleEntryProto) -> Tuple[errors.Status, Optional[tensor.Tensor]]:
    stored_shape = tensor_shape.TensorShape.from_proto(entry.shape)
    ret = tensor.Tensor(entry.dtype, stored_shape)
    s, file = self.get_file(entry)
    if not s.ok():
      return s, None
    s, mm = self.get_mmap(entry)
    if not s.ok():
      s, sp = file.read(entry.offset, entry.size)
      if not s.ok():
        return s, None
      buf = tensor.TensorBuffer(sp.bytes())
    else:
      array_offset = entry.offset
      buf = tensor.TensorBuffer(mm, array_offset, order="C")
    ret.set_data(buf)
    return errors.Status.OK(), ret

  def get_numpy(self, entry: tensor_bundle_pb2.BundleEntryProto) -> Tuple[errors.Status, Optional[np.ndarray]]:
    s, tensor_value = self.get_value(entry)
    if not s.ok():
      return s, None
    return tensor_value.to_py()





'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/autotuning.proto', package='tensorflow', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n)tensorflow/core/protobuf/autotuning.proto\x12\ntensorflow\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto";\n\x0cCudnnVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05patch\x18\x03 \x01(\x05"1\n\x11ComputeCapability\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05"\xc9\x06\n\x0eAutotuneResult\x12\x15\n\rscratch_bytes\x18\x08 \x01(\x03\x12+\n\x08run_time\x18\t \x01(\x0b2\x19.google.protobuf.Duration\x129\n\x07failure\x18\x07 \x01(\x0b2(.tensorflow.AutotuneResult.FailureResult\x122\n\x04conv\x18\x05 \x01(\x0b2".tensorflow.AutotuneResult.ConvKeyH\x00\x122\n\x04gemm\x18\x06 \x01(\x0b2".tensorflow.AutotuneResult.GemmKeyH\x00\x12D\n\x0ecuda_conv_plan\x18\x0f \x01(\x0b2*.tensorflow.AutotuneResult.CudaConvPlanKeyH\x00\x1a\xbd\x02\n\rFailureResult\x124\n\x04kind\x18\x01 \x01(\x0e2&.tensorflow.AutotuneResult.FailureKind\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12<\n\x0ereference_conv\x18\x0b \x01(\x0b2".tensorflow.AutotuneResult.ConvKeyH\x00\x12<\n\x0ereference_gemm\x18\x0c \x01(\x0b2".tensorflow.AutotuneResult.GemmKeyH\x00\x12N\n\x18reference_cuda_conv_plan\x18\x0e \x01(\x0b2*.tensorflow.AutotuneResult.CudaConvPlanKeyH\x00\x12\x16\n\x0ebuffer_address\x18\r \x01(\x03B\x05\n\x03key\x1a8\n\x07ConvKey\x12\x11\n\talgorithm\x18\x01 \x01(\x03\x12\x1a\n\x12tensor_ops_enabled\x18\x02 \x01(\x08\x1a\x1c\n\x07GemmKey\x12\x11\n\talgorithm\x18\x01 \x01(\x03\x1a\'\n\x0fCudaConvPlanKey\x12\x14\n\x0cexec_plan_id\x18\x01 \x01(\t"B\n\x0bFailureKind\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10REDZONE_MODIFIED\x10\x01\x12\x10\n\x0cWRONG_RESULT\x10\x02B\x05\n\x03key"\xfe\x01\n\rAutotuningLog\x12#\n\x05instr\x18\x01 \x01(\x0b2\x14.google.protobuf.Any\x12+\n\x07results\x18\x02 \x03(\x0b2\x1a.tensorflow.AutotuneResult\x12/\n\rcudnn_version\x18\x03 \x01(\x0b2\x18.tensorflow.CudnnVersion\x129\n\x12compute_capability\x18\x04 \x01(\x0b2\x1d.tensorflow.ComputeCapability\x12\x19\n\x11device_pci_bus_id\x18\x05 \x01(\t\x12\x14\n\x0cblas_version\x18\x06 \x01(\tBWZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3', dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR, google_dot_protobuf_dot_duration__pb2.DESCRIPTOR])
_AUTOTUNERESULT_FAILUREKIND = _descriptor.EnumDescriptor(name='FailureKind', full_name='tensorflow.AutotuneResult.FailureKind', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNKNOWN', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='REDZONE_MODIFIED', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='WRONG_RESULT', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=997, serialized_end=1063)
_sym_db.RegisterEnumDescriptor(_AUTOTUNERESULT_FAILUREKIND)
_CUDNNVERSION = _descriptor.Descriptor(name='CudnnVersion', full_name='tensorflow.CudnnVersion', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='major', full_name='tensorflow.CudnnVersion.major', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='minor', full_name='tensorflow.CudnnVersion.minor', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='patch', full_name='tensorflow.CudnnVersion.patch', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=116, serialized_end=175)
_COMPUTECAPABILITY = _descriptor.Descriptor(name='ComputeCapability', full_name='tensorflow.ComputeCapability', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='major', full_name='tensorflow.ComputeCapability.major', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='minor', full_name='tensorflow.ComputeCapability.minor', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=177, serialized_end=226)
_AUTOTUNERESULT_FAILURERESULT = _descriptor.Descriptor(name='FailureResult', full_name='tensorflow.AutotuneResult.FailureResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='kind', full_name='tensorflow.AutotuneResult.FailureResult.kind', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='msg', full_name='tensorflow.AutotuneResult.FailureResult.msg', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='reference_conv', full_name='tensorflow.AutotuneResult.FailureResult.reference_conv', index=2, number=11, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='reference_gemm', full_name='tensorflow.AutotuneResult.FailureResult.reference_gemm', index=3, number=12, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='reference_cuda_conv_plan', full_name='tensorflow.AutotuneResult.FailureResult.reference_cuda_conv_plan', index=4, number=14, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='buffer_address', full_name='tensorflow.AutotuneResult.FailureResult.buffer_address', index=5, number=13, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='key', full_name='tensorflow.AutotuneResult.FailureResult.key', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=549, serialized_end=866)
_AUTOTUNERESULT_CONVKEY = _descriptor.Descriptor(name='ConvKey', full_name='tensorflow.AutotuneResult.ConvKey', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='algorithm', full_name='tensorflow.AutotuneResult.ConvKey.algorithm', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_ops_enabled', full_name='tensorflow.AutotuneResult.ConvKey.tensor_ops_enabled', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=868, serialized_end=924)
_AUTOTUNERESULT_GEMMKEY = _descriptor.Descriptor(name='GemmKey', full_name='tensorflow.AutotuneResult.GemmKey', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='algorithm', full_name='tensorflow.AutotuneResult.GemmKey.algorithm', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=926, serialized_end=954)
_AUTOTUNERESULT_CUDACONVPLANKEY = _descriptor.Descriptor(name='CudaConvPlanKey', full_name='tensorflow.AutotuneResult.CudaConvPlanKey', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='exec_plan_id', full_name='tensorflow.AutotuneResult.CudaConvPlanKey.exec_plan_id', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=956, serialized_end=995)
_AUTOTUNERESULT = _descriptor.Descriptor(name='AutotuneResult', full_name='tensorflow.AutotuneResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='scratch_bytes', full_name='tensorflow.AutotuneResult.scratch_bytes', index=0, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_time', full_name='tensorflow.AutotuneResult.run_time', index=1, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='failure', full_name='tensorflow.AutotuneResult.failure', index=2, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='conv', full_name='tensorflow.AutotuneResult.conv', index=3, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='gemm', full_name='tensorflow.AutotuneResult.gemm', index=4, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cuda_conv_plan', full_name='tensorflow.AutotuneResult.cuda_conv_plan', index=5, number=15, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_AUTOTUNERESULT_FAILURERESULT, _AUTOTUNERESULT_CONVKEY, _AUTOTUNERESULT_GEMMKEY, _AUTOTUNERESULT_CUDACONVPLANKEY], enum_types=[_AUTOTUNERESULT_FAILUREKIND], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='key', full_name='tensorflow.AutotuneResult.key', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=229, serialized_end=1070)
_AUTOTUNINGLOG = _descriptor.Descriptor(name='AutotuningLog', full_name='tensorflow.AutotuningLog', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='instr', full_name='tensorflow.AutotuningLog.instr', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='results', full_name='tensorflow.AutotuningLog.results', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cudnn_version', full_name='tensorflow.AutotuningLog.cudnn_version', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compute_capability', full_name='tensorflow.AutotuningLog.compute_capability', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_pci_bus_id', full_name='tensorflow.AutotuningLog.device_pci_bus_id', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='blas_version', full_name='tensorflow.AutotuningLog.blas_version', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1073, serialized_end=1327)
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['kind'].enum_type = _AUTOTUNERESULT_FAILUREKIND
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_conv'].message_type = _AUTOTUNERESULT_CONVKEY
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_gemm'].message_type = _AUTOTUNERESULT_GEMMKEY
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_cuda_conv_plan'].message_type = _AUTOTUNERESULT_CUDACONVPLANKEY
_AUTOTUNERESULT_FAILURERESULT.containing_type = _AUTOTUNERESULT
_AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_conv'])
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_conv'].containing_oneof = _AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key']
_AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_gemm'])
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_gemm'].containing_oneof = _AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key']
_AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_cuda_conv_plan'])
_AUTOTUNERESULT_FAILURERESULT.fields_by_name['reference_cuda_conv_plan'].containing_oneof = _AUTOTUNERESULT_FAILURERESULT.oneofs_by_name['key']
_AUTOTUNERESULT_CONVKEY.containing_type = _AUTOTUNERESULT
_AUTOTUNERESULT_GEMMKEY.containing_type = _AUTOTUNERESULT
_AUTOTUNERESULT_CUDACONVPLANKEY.containing_type = _AUTOTUNERESULT
_AUTOTUNERESULT.fields_by_name['run_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_AUTOTUNERESULT.fields_by_name['failure'].message_type = _AUTOTUNERESULT_FAILURERESULT
_AUTOTUNERESULT.fields_by_name['conv'].message_type = _AUTOTUNERESULT_CONVKEY
_AUTOTUNERESULT.fields_by_name['gemm'].message_type = _AUTOTUNERESULT_GEMMKEY
_AUTOTUNERESULT.fields_by_name['cuda_conv_plan'].message_type = _AUTOTUNERESULT_CUDACONVPLANKEY
_AUTOTUNERESULT_FAILUREKIND.containing_type = _AUTOTUNERESULT
_AUTOTUNERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT.fields_by_name['conv'])
_AUTOTUNERESULT.fields_by_name['conv'].containing_oneof = _AUTOTUNERESULT.oneofs_by_name['key']
_AUTOTUNERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT.fields_by_name['gemm'])
_AUTOTUNERESULT.fields_by_name['gemm'].containing_oneof = _AUTOTUNERESULT.oneofs_by_name['key']
_AUTOTUNERESULT.oneofs_by_name['key'].fields.append(_AUTOTUNERESULT.fields_by_name['cuda_conv_plan'])
_AUTOTUNERESULT.fields_by_name['cuda_conv_plan'].containing_oneof = _AUTOTUNERESULT.oneofs_by_name['key']
_AUTOTUNINGLOG.fields_by_name['instr'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_AUTOTUNINGLOG.fields_by_name['results'].message_type = _AUTOTUNERESULT
_AUTOTUNINGLOG.fields_by_name['cudnn_version'].message_type = _CUDNNVERSION
_AUTOTUNINGLOG.fields_by_name['compute_capability'].message_type = _COMPUTECAPABILITY
DESCRIPTOR.message_types_by_name['CudnnVersion'] = _CUDNNVERSION
DESCRIPTOR.message_types_by_name['ComputeCapability'] = _COMPUTECAPABILITY
DESCRIPTOR.message_types_by_name['AutotuneResult'] = _AUTOTUNERESULT
DESCRIPTOR.message_types_by_name['AutotuningLog'] = _AUTOTUNINGLOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CudnnVersion = _reflection.GeneratedProtocolMessageType('CudnnVersion', (_message.Message,), {'DESCRIPTOR': _CUDNNVERSION, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'})
_sym_db.RegisterMessage(CudnnVersion)
ComputeCapability = _reflection.GeneratedProtocolMessageType('ComputeCapability', (_message.Message,), {'DESCRIPTOR': _COMPUTECAPABILITY, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'})
_sym_db.RegisterMessage(ComputeCapability)
AutotuneResult = _reflection.GeneratedProtocolMessageType('AutotuneResult', (_message.Message,), {'FailureResult': _reflection.GeneratedProtocolMessageType('FailureResult', (_message.Message,), {'DESCRIPTOR': _AUTOTUNERESULT_FAILURERESULT, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'}), 'ConvKey': _reflection.GeneratedProtocolMessageType('ConvKey', (_message.Message,), {'DESCRIPTOR': _AUTOTUNERESULT_CONVKEY, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'}), 'GemmKey': _reflection.GeneratedProtocolMessageType('GemmKey', (_message.Message,), {'DESCRIPTOR': _AUTOTUNERESULT_GEMMKEY, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'}), 'CudaConvPlanKey': _reflection.GeneratedProtocolMessageType('CudaConvPlanKey', (_message.Message,), {'DESCRIPTOR': _AUTOTUNERESULT_CUDACONVPLANKEY, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'}), 'DESCRIPTOR': _AUTOTUNERESULT, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'})
_sym_db.RegisterMessage(AutotuneResult)
_sym_db.RegisterMessage(AutotuneResult.FailureResult)
_sym_db.RegisterMessage(AutotuneResult.ConvKey)
_sym_db.RegisterMessage(AutotuneResult.GemmKey)
_sym_db.RegisterMessage(AutotuneResult.CudaConvPlanKey)
AutotuningLog = _reflection.GeneratedProtocolMessageType('AutotuningLog', (_message.Message,), {'DESCRIPTOR': _AUTOTUNINGLOG, '__module__': 'tensorflow.core.protobuf.autotuning_pb2'})
_sym_db.RegisterMessage(AutotuningLog)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/stream_executor/dnn.proto', package='stream_executor.dnn', syntax='proto3', serialized_options=b'Z>github.com/tensorflow/tensorflow/tensorflow/go/stream_executor', create_key=_descriptor._internal_create_key, serialized_pb=b'\n$tensorflow/stream_executor/dnn.proto\x12\x13stream_executor.dnn"\xe1\x01\n\x15TensorDescriptorProto\x12\x12\n\ndimensions\x18\x01 \x03(\x03\x120\n\tdata_type\x18\x02 \x01(\x0e2\x1d.stream_executor.dnn.DataType\x126\n\x0bdata_layout\x18\x03 \x01(\x0e2\x1f.stream_executor.dnn.DataLayoutH\x00\x12:\n\rfilter_layout\x18\x04 \x01(\x0e2!.stream_executor.dnn.FilterLayoutH\x00B\x0e\n\x0clayout_oneof"\xaa\x01\n\x0eAlgorithmProto\x12\x0f\n\x07algo_id\x18\x01 \x01(\x03\x12?\n\tmath_type\x18\x02 \x01(\x0e2,.stream_executor.dnn.AlgorithmProto.MathType\x12\x14\n\x0cexec_plan_id\x18\x03 \x01(\t"0\n\x08MathType\x12\x10\n\x0cDEFAULT_MATH\x10\x00\x12\x12\n\x0eTENSOR_OP_MATH\x10\x01"\xea\x01\n\x1aConvolutionDescriptorProto\x12\x10\n\x08paddings\x18\x01 \x03(\x03\x12\x0f\n\x07strides\x18\x02 \x03(\x03\x12\x11\n\tdilations\x18\x03 \x03(\x03\x123\n\x0ccompute_mode\x18\x04 \x01(\x0e2\x1d.stream_executor.dnn.DataType\x12\x13\n\x0bgroup_count\x18\x05 \x01(\x05\x12>\n\x10convolution_mode\x18\x06 \x01(\x0e2$.stream_executor.dnn.ConvolutionMode\x12\x0c\n\x04name\x18\x07 \x01(\t*w\n\x08DataType\x12\n\n\x06kFloat\x10\x00\x12\x0b\n\x07kDouble\x10\x01\x12\t\n\x05kHalf\x10\x02\x12\t\n\x05kInt8\x10\x03\x12\n\n\x06kInt32\x10\x04\x12\x11\n\rkComplexFloat\x10\x05\x12\x12\n\x0ekComplexDouble\x10\x06\x12\t\n\x05kBF16\x10\x07*\x81\x01\n\nDataLayout\x12\x11\n\rkYXDepthBatch\x10\x00\x12\x11\n\rkYXBatchDepth\x10\x01\x12\x11\n\rkBatchYXDepth\x10\x02\x12\x11\n\rkBatchDepthYX\x10\x03\x12\x12\n\x0ekBatchDepthYX4\x10\x04\x12\x13\n\x0fkBatchDepthYX32\x10\x05*\x89\x01\n\x0cFilterLayout\x12\x12\n\x0ekOutputInputYX\x10\x00\x12\x12\n\x0ekOutputYXInput\x10\x01\x12\x13\n\x0fkOutputInputYX4\x10\x02\x12\x14\n\x10kOutputInputYX32\x10\x05\x12\x12\n\x0ekInputYXOutput\x10\x03\x12\x12\n\x0ekYXInputOutput\x10\x04*f\n\x0eActivationMode\x12\t\n\x05kNone\x10\x00\x12\x0c\n\x08kSigmoid\x10\x01\x12\t\n\x05kRelu\x10\x02\x12\n\n\x06kRelu6\x10\x03\x12\n\n\x06kReluX\x10\x04\x12\t\n\x05kTanh\x10\x05\x12\r\n\tkBandPass\x10\x06*9\n\x0fConvolutionMode\x12\x15\n\x11CROSS_CORRELATION\x10\x00\x12\x0f\n\x0bCONVOLUTION\x10\x01*p\n\x0fConvolutionKind\x12\x0b\n\x07INVALID\x10\x00\x12\x0b\n\x07FORWARD\x10\x01\x12\x13\n\x0fBACKWARD_FILTER\x10\x02\x12\x11\n\rBACKWARD_DATA\x10\x03\x12\x1b\n\x17FORWARD_BIAS_ACTIVATION\x10\x04B@Z>github.com/tensorflow/tensorflow/tensorflow/go/stream_executorb\x06proto3')
_DATATYPE = _descriptor.EnumDescriptor(name='DataType', full_name='stream_executor.dnn.DataType', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='kFloat', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kDouble', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kHalf', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kInt8', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kInt32', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kComplexFloat', index=5, number=5, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kComplexDouble', index=6, number=6, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kBF16', index=7, number=7, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=699, serialized_end=818)
_sym_db.RegisterEnumDescriptor(_DATATYPE)
DataType = enum_type_wrapper.EnumTypeWrapper(_DATATYPE)
_DATALAYOUT = _descriptor.EnumDescriptor(name='DataLayout', full_name='stream_executor.dnn.DataLayout', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='kYXDepthBatch', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kYXBatchDepth', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kBatchYXDepth', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kBatchDepthYX', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kBatchDepthYX4', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kBatchDepthYX32', index=5, number=5, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=821, serialized_end=950)
_sym_db.RegisterEnumDescriptor(_DATALAYOUT)
DataLayout = enum_type_wrapper.EnumTypeWrapper(_DATALAYOUT)
_FILTERLAYOUT = _descriptor.EnumDescriptor(name='FilterLayout', full_name='stream_executor.dnn.FilterLayout', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='kOutputInputYX', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kOutputYXInput', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kOutputInputYX4', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kOutputInputYX32', index=3, number=5, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kInputYXOutput', index=4, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kYXInputOutput', index=5, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=953, serialized_end=1090)
_sym_db.RegisterEnumDescriptor(_FILTERLAYOUT)
FilterLayout = enum_type_wrapper.EnumTypeWrapper(_FILTERLAYOUT)
_ACTIVATIONMODE = _descriptor.EnumDescriptor(name='ActivationMode', full_name='stream_executor.dnn.ActivationMode', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='kNone', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kSigmoid', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kRelu', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kRelu6', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kReluX', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kTanh', index=5, number=5, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='kBandPass', index=6, number=6, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1092, serialized_end=1194)
_sym_db.RegisterEnumDescriptor(_ACTIVATIONMODE)
ActivationMode = enum_type_wrapper.EnumTypeWrapper(_ACTIVATIONMODE)
_CONVOLUTIONMODE = _descriptor.EnumDescriptor(name='ConvolutionMode', full_name='stream_executor.dnn.ConvolutionMode', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='CROSS_CORRELATION', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='CONVOLUTION', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1196, serialized_end=1253)
_sym_db.RegisterEnumDescriptor(_CONVOLUTIONMODE)
ConvolutionMode = enum_type_wrapper.EnumTypeWrapper(_CONVOLUTIONMODE)
_CONVOLUTIONKIND = _descriptor.EnumDescriptor(name='ConvolutionKind', full_name='stream_executor.dnn.ConvolutionKind', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='FORWARD', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='BACKWARD_FILTER', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='BACKWARD_DATA', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='FORWARD_BIAS_ACTIVATION', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1255, serialized_end=1367)
_sym_db.RegisterEnumDescriptor(_CONVOLUTIONKIND)
ConvolutionKind = enum_type_wrapper.EnumTypeWrapper(_CONVOLUTIONKIND)
kFloat = 0
kDouble = 1
kHalf = 2
kInt8 = 3
kInt32 = 4
kComplexFloat = 5
kComplexDouble = 6
kBF16 = 7
kYXDepthBatch = 0
kYXBatchDepth = 1
kBatchYXDepth = 2
kBatchDepthYX = 3
kBatchDepthYX4 = 4
kBatchDepthYX32 = 5
kOutputInputYX = 0
kOutputYXInput = 1
kOutputInputYX4 = 2
kOutputInputYX32 = 5
kInputYXOutput = 3
kYXInputOutput = 4
kNone = 0
kSigmoid = 1
kRelu = 2
kRelu6 = 3
kReluX = 4
kTanh = 5
kBandPass = 6
CROSS_CORRELATION = 0
CONVOLUTION = 1
INVALID = 0
FORWARD = 1
BACKWARD_FILTER = 2
BACKWARD_DATA = 3
FORWARD_BIAS_ACTIVATION = 4
_ALGORITHMPROTO_MATHTYPE = _descriptor.EnumDescriptor(name='MathType', full_name='stream_executor.dnn.AlgorithmProto.MathType', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='DEFAULT_MATH', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TENSOR_OP_MATH', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=412, serialized_end=460)
_sym_db.RegisterEnumDescriptor(_ALGORITHMPROTO_MATHTYPE)
_TENSORDESCRIPTORPROTO = _descriptor.Descriptor(name='TensorDescriptorProto', full_name='stream_executor.dnn.TensorDescriptorProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dimensions', full_name='stream_executor.dnn.TensorDescriptorProto.dimensions', index=0, number=1, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data_type', full_name='stream_executor.dnn.TensorDescriptorProto.data_type', index=1, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data_layout', full_name='stream_executor.dnn.TensorDescriptorProto.data_layout', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='filter_layout', full_name='stream_executor.dnn.TensorDescriptorProto.filter_layout', index=3, number=4, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='layout_oneof', full_name='stream_executor.dnn.TensorDescriptorProto.layout_oneof', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=62, serialized_end=287)
_ALGORITHMPROTO = _descriptor.Descriptor(name='AlgorithmProto', full_name='stream_executor.dnn.AlgorithmProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='algo_id', full_name='stream_executor.dnn.AlgorithmProto.algo_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='math_type', full_name='stream_executor.dnn.AlgorithmProto.math_type', index=1, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='exec_plan_id', full_name='stream_executor.dnn.AlgorithmProto.exec_plan_id', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_ALGORITHMPROTO_MATHTYPE], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=290, serialized_end=460)
_CONVOLUTIONDESCRIPTORPROTO = _descriptor.Descriptor(name='ConvolutionDescriptorProto', full_name='stream_executor.dnn.ConvolutionDescriptorProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='paddings', full_name='stream_executor.dnn.ConvolutionDescriptorProto.paddings', index=0, number=1, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='strides', full_name='stream_executor.dnn.ConvolutionDescriptorProto.strides', index=1, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dilations', full_name='stream_executor.dnn.ConvolutionDescriptorProto.dilations', index=2, number=3, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='compute_mode', full_name='stream_executor.dnn.ConvolutionDescriptorProto.compute_mode', index=3, number=4, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='group_count', full_name='stream_executor.dnn.ConvolutionDescriptorProto.group_count', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='convolution_mode', full_name='stream_executor.dnn.ConvolutionDescriptorProto.convolution_mode', index=5, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='stream_executor.dnn.ConvolutionDescriptorProto.name', index=6, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=463, serialized_end=697)
_TENSORDESCRIPTORPROTO.fields_by_name['data_type'].enum_type = _DATATYPE
_TENSORDESCRIPTORPROTO.fields_by_name['data_layout'].enum_type = _DATALAYOUT
_TENSORDESCRIPTORPROTO.fields_by_name['filter_layout'].enum_type = _FILTERLAYOUT
_TENSORDESCRIPTORPROTO.oneofs_by_name['layout_oneof'].fields.append(_TENSORDESCRIPTORPROTO.fields_by_name['data_layout'])
_TENSORDESCRIPTORPROTO.fields_by_name['data_layout'].containing_oneof = _TENSORDESCRIPTORPROTO.oneofs_by_name['layout_oneof']
_TENSORDESCRIPTORPROTO.oneofs_by_name['layout_oneof'].fields.append(_TENSORDESCRIPTORPROTO.fields_by_name['filter_layout'])
_TENSORDESCRIPTORPROTO.fields_by_name['filter_layout'].containing_oneof = _TENSORDESCRIPTORPROTO.oneofs_by_name['layout_oneof']
_ALGORITHMPROTO.fields_by_name['math_type'].enum_type = _ALGORITHMPROTO_MATHTYPE
_ALGORITHMPROTO_MATHTYPE.containing_type = _ALGORITHMPROTO
_CONVOLUTIONDESCRIPTORPROTO.fields_by_name['compute_mode'].enum_type = _DATATYPE
_CONVOLUTIONDESCRIPTORPROTO.fields_by_name['convolution_mode'].enum_type = _CONVOLUTIONMODE
DESCRIPTOR.message_types_by_name['TensorDescriptorProto'] = _TENSORDESCRIPTORPROTO
DESCRIPTOR.message_types_by_name['AlgorithmProto'] = _ALGORITHMPROTO
DESCRIPTOR.message_types_by_name['ConvolutionDescriptorProto'] = _CONVOLUTIONDESCRIPTORPROTO
DESCRIPTOR.enum_types_by_name['DataType'] = _DATATYPE
DESCRIPTOR.enum_types_by_name['DataLayout'] = _DATALAYOUT
DESCRIPTOR.enum_types_by_name['FilterLayout'] = _FILTERLAYOUT
DESCRIPTOR.enum_types_by_name['ActivationMode'] = _ACTIVATIONMODE
DESCRIPTOR.enum_types_by_name['ConvolutionMode'] = _CONVOLUTIONMODE
DESCRIPTOR.enum_types_by_name['ConvolutionKind'] = _CONVOLUTIONKIND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TensorDescriptorProto = _reflection.GeneratedProtocolMessageType('TensorDescriptorProto', (_message.Message,), {'DESCRIPTOR': _TENSORDESCRIPTORPROTO, '__module__': 'tensorflow.stream_executor.dnn_pb2'})
_sym_db.RegisterMessage(TensorDescriptorProto)
AlgorithmProto = _reflection.GeneratedProtocolMessageType('AlgorithmProto', (_message.Message,), {'DESCRIPTOR': _ALGORITHMPROTO, '__module__': 'tensorflow.stream_executor.dnn_pb2'})
_sym_db.RegisterMessage(AlgorithmProto)
ConvolutionDescriptorProto = _reflection.GeneratedProtocolMessageType('ConvolutionDescriptorProto', (_message.Message,), {'DESCRIPTOR': _CONVOLUTIONDESCRIPTORPROTO, '__module__': 'tensorflow.stream_executor.dnn_pb2'})
_sym_db.RegisterMessage(ConvolutionDescriptorProto)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.protobuf import master_pb2 as tensorflow_dot_core_dot_protobuf_dot_master__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/replay_log.proto', package='tensorflow', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n)tensorflow/core/protobuf/replay_log.proto\x12\ntensorflow\x1a%tensorflow/core/protobuf/master.proto"\\\n\x10NewReplaySession\x120\n\x07devices\x18\x01 \x01(\x0b2\x1f.tensorflow.ListDevicesResponse\x12\x16\n\x0esession_handle\x18\x02 \x01(\t"\xe8\n\n\x08ReplayOp\x12\x15\n\rstart_time_us\x18\x1f \x01(\x01\x12\x13\n\x0bend_time_us\x18  \x01(\x01\x12:\n\x0ecreate_session\x18\x01 \x01(\x0b2 .tensorflow.CreateSessionRequestH\x00\x12:\n\x0eextend_session\x18\x02 \x01(\x0b2 .tensorflow.ExtendSessionRequestH\x00\x12?\n\x11partial_run_setup\x18\x03 \x01(\x0b2".tensorflow.PartialRunSetupRequestH\x00\x12.\n\x08run_step\x18\x04 \x01(\x0b2\x1a.tensorflow.RunStepRequestH\x00\x128\n\rclose_session\x18\x05 \x01(\x0b2\x1f.tensorflow.CloseSessionRequestH\x00\x126\n\x0clist_devices\x18\x06 \x01(\x0b2\x1e.tensorflow.ListDevicesRequestH\x00\x121\n\rreset_request\x18\x07 \x01(\x0b2\x18.tensorflow.ResetRequestH\x00\x128\n\rmake_callable\x18\x08 \x01(\x0b2\x1f.tensorflow.MakeCallableRequestH\x00\x126\n\x0crun_callable\x18\t \x01(\x0b2\x1e.tensorflow.RunCallableRequestH\x00\x12>\n\x10release_callable\x18\n \x01(\x0b2".tensorflow.ReleaseCallableRequestH\x00\x12:\n\x12new_replay_session\x18\x0b \x01(\x0b2\x1c.tensorflow.NewReplaySessionH\x00\x12D\n\x17create_session_response\x18\x15 \x01(\x0b2!.tensorflow.CreateSessionResponseH\x01\x12D\n\x17extend_session_response\x18\x16 \x01(\x0b2!.tensorflow.ExtendSessionResponseH\x01\x12I\n\x1apartial_run_setup_response\x18\x17 \x01(\x0b2#.tensorflow.PartialRunSetupResponseH\x01\x128\n\x11run_step_response\x18\x18 \x01(\x0b2\x1b.tensorflow.RunStepResponseH\x01\x12B\n\x16close_session_response\x18\x19 \x01(\x0b2 .tensorflow.CloseSessionResponseH\x01\x12@\n\x15list_devices_response\x18\x1a \x01(\x0b2\x1f.tensorflow.ListDevicesResponseH\x01\x12;\n\x16reset_request_response\x18\x1b \x01(\x0b2\x19.tensorflow.ResetResponseH\x01\x12B\n\x16make_callable_response\x18\x1c \x01(\x0b2 .tensorflow.MakeCallableResponseH\x01\x12@\n\x15run_callable_response\x18\x1d \x01(\x0b2\x1f.tensorflow.RunCallableResponseH\x01\x12H\n\x19release_callable_response\x18\x1e \x01(\x0b2#.tensorflow.ReleaseCallableResponseH\x01B\x04\n\x02opB\n\n\x08responseBZZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_protobuf_dot_master__pb2.DESCRIPTOR])
_NEWREPLAYSESSION = _descriptor.Descriptor(name='NewReplaySession', full_name='tensorflow.NewReplaySession', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='devices', full_name='tensorflow.NewReplaySession.devices', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='session_handle', full_name='tensorflow.NewReplaySession.session_handle', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=96, serialized_end=188)
_REPLAYOP = _descriptor.Descriptor(name='ReplayOp', full_name='tensorflow.ReplayOp', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='start_time_us', full_name='tensorflow.ReplayOp.start_time_us', index=0, number=31, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_time_us', full_name='tensorflow.ReplayOp.end_time_us', index=1, number=32, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='create_session', full_name='tensorflow.ReplayOp.create_session', index=2, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extend_session', full_name='tensorflow.ReplayOp.extend_session', index=3, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='partial_run_setup', full_name='tensorflow.ReplayOp.partial_run_setup', index=4, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_step', full_name='tensorflow.ReplayOp.run_step', index=5, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='close_session', full_name='tensorflow.ReplayOp.close_session', index=6, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='list_devices', full_name='tensorflow.ReplayOp.list_devices', index=7, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='reset_request', full_name='tensorflow.ReplayOp.reset_request', index=8, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='make_callable', full_name='tensorflow.ReplayOp.make_callable', index=9, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_callable', full_name='tensorflow.ReplayOp.run_callable', index=10, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='release_callable', full_name='tensorflow.ReplayOp.release_callable', index=11, number=10, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='new_replay_session', full_name='tensorflow.ReplayOp.new_replay_session', index=12, number=11, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='create_session_response', full_name='tensorflow.ReplayOp.create_session_response', index=13, number=21, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extend_session_response', full_name='tensorflow.ReplayOp.extend_session_response', index=14, number=22, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='partial_run_setup_response', full_name='tensorflow.ReplayOp.partial_run_setup_response', index=15, number=23, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_step_response', full_name='tensorflow.ReplayOp.run_step_response', index=16, number=24, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='close_session_response', full_name='tensorflow.ReplayOp.close_session_response', index=17, number=25, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='list_devices_response', full_name='tensorflow.ReplayOp.list_devices_response', index=18, number=26, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='reset_request_response', full_name='tensorflow.ReplayOp.reset_request_response', index=19, number=27, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='make_callable_response', full_name='tensorflow.ReplayOp.make_callable_response', index=20, number=28, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_callable_response', full_name='tensorflow.ReplayOp.run_callable_response', index=21, number=29, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='release_callable_response', full_name='tensorflow.ReplayOp.release_callable_response', index=22, number=30, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='op', full_name='tensorflow.ReplayOp.op', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='response', full_name='tensorflow.ReplayOp.response', index=1, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=191, serialized_end=1575)
_NEWREPLAYSESSION.fields_by_name['devices'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._LISTDEVICESRESPONSE
_REPLAYOP.fields_by_name['create_session'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._CREATESESSIONREQUEST
_REPLAYOP.fields_by_name['extend_session'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._EXTENDSESSIONREQUEST
_REPLAYOP.fields_by_name['partial_run_setup'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._PARTIALRUNSETUPREQUEST
_REPLAYOP.fields_by_name['run_step'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._RUNSTEPREQUEST
_REPLAYOP.fields_by_name['close_session'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._CLOSESESSIONREQUEST
_REPLAYOP.fields_by_name['list_devices'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._LISTDEVICESREQUEST
_REPLAYOP.fields_by_name['reset_request'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._RESETREQUEST
_REPLAYOP.fields_by_name['make_callable'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._MAKECALLABLEREQUEST
_REPLAYOP.fields_by_name['run_callable'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._RUNCALLABLEREQUEST
_REPLAYOP.fields_by_name['release_callable'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._RELEASECALLABLEREQUEST
_REPLAYOP.fields_by_name['new_replay_session'].message_type = _NEWREPLAYSESSION
_REPLAYOP.fields_by_name['create_session_response'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._CREATESESSIONRESPONSE
_REPLAYOP.fields_by_name['extend_session_response'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._EXTENDSESSIONRESPONSE
_REPLAYOP.fields_by_name['partial_run_setup_response'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._PARTIALRUNSETUPRESPONSE
_REPLAYOP.fields_by_name['run_step_response'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._RUNSTEPRESPONSE
_REPLAYOP.fields_by_name['close_session_response'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._CLOSESESSIONRESPONSE
_REPLAYOP.fields_by_name['list_devices_response'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._LISTDEVICESRESPONSE
_REPLAYOP.fields_by_name['reset_request_response'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._RESETRESPONSE
_REPLAYOP.fields_by_name['make_callable_response'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._MAKECALLABLERESPONSE
_REPLAYOP.fields_by_name['run_callable_response'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._RUNCALLABLERESPONSE
_REPLAYOP.fields_by_name['release_callable_response'].message_type = tensorflow_dot_core_dot_protobuf_dot_master__pb2._RELEASECALLABLERESPONSE
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['create_session'])
_REPLAYOP.fields_by_name['create_session'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['extend_session'])
_REPLAYOP.fields_by_name['extend_session'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['partial_run_setup'])
_REPLAYOP.fields_by_name['partial_run_setup'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['run_step'])
_REPLAYOP.fields_by_name['run_step'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['close_session'])
_REPLAYOP.fields_by_name['close_session'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['list_devices'])
_REPLAYOP.fields_by_name['list_devices'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['reset_request'])
_REPLAYOP.fields_by_name['reset_request'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['make_callable'])
_REPLAYOP.fields_by_name['make_callable'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['run_callable'])
_REPLAYOP.fields_by_name['run_callable'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['release_callable'])
_REPLAYOP.fields_by_name['release_callable'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['op'].fields.append(_REPLAYOP.fields_by_name['new_replay_session'])
_REPLAYOP.fields_by_name['new_replay_session'].containing_oneof = _REPLAYOP.oneofs_by_name['op']
_REPLAYOP.oneofs_by_name['response'].fields.append(_REPLAYOP.fields_by_name['create_session_response'])
_REPLAYOP.fields_by_name['create_session_response'].containing_oneof = _REPLAYOP.oneofs_by_name['response']
_REPLAYOP.oneofs_by_name['response'].fields.append(_REPLAYOP.fields_by_name['extend_session_response'])
_REPLAYOP.fields_by_name['extend_session_response'].containing_oneof = _REPLAYOP.oneofs_by_name['response']
_REPLAYOP.oneofs_by_name['response'].fields.append(_REPLAYOP.fields_by_name['partial_run_setup_response'])
_REPLAYOP.fields_by_name['partial_run_setup_response'].containing_oneof = _REPLAYOP.oneofs_by_name['response']
_REPLAYOP.oneofs_by_name['response'].fields.append(_REPLAYOP.fields_by_name['run_step_response'])
_REPLAYOP.fields_by_name['run_step_response'].containing_oneof = _REPLAYOP.oneofs_by_name['response']
_REPLAYOP.oneofs_by_name['response'].fields.append(_REPLAYOP.fields_by_name['close_session_response'])
_REPLAYOP.fields_by_name['close_session_response'].containing_oneof = _REPLAYOP.oneofs_by_name['response']
_REPLAYOP.oneofs_by_name['response'].fields.append(_REPLAYOP.fields_by_name['list_devices_response'])
_REPLAYOP.fields_by_name['list_devices_response'].containing_oneof = _REPLAYOP.oneofs_by_name['response']
_REPLAYOP.oneofs_by_name['response'].fields.append(_REPLAYOP.fields_by_name['reset_request_response'])
_REPLAYOP.fields_by_name['reset_request_response'].containing_oneof = _REPLAYOP.oneofs_by_name['response']
_REPLAYOP.oneofs_by_name['response'].fields.append(_REPLAYOP.fields_by_name['make_callable_response'])
_REPLAYOP.fields_by_name['make_callable_response'].containing_oneof = _REPLAYOP.oneofs_by_name['response']
_REPLAYOP.oneofs_by_name['response'].fields.append(_REPLAYOP.fields_by_name['run_callable_response'])
_REPLAYOP.fields_by_name['run_callable_response'].containing_oneof = _REPLAYOP.oneofs_by_name['response']
_REPLAYOP.oneofs_by_name['response'].fields.append(_REPLAYOP.fields_by_name['release_callable_response'])
_REPLAYOP.fields_by_name['release_callable_response'].containing_oneof = _REPLAYOP.oneofs_by_name['response']
DESCRIPTOR.message_types_by_name['NewReplaySession'] = _NEWREPLAYSESSION
DESCRIPTOR.message_types_by_name['ReplayOp'] = _REPLAYOP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
NewReplaySession = _reflection.GeneratedProtocolMessageType('NewReplaySession', (_message.Message,), {'DESCRIPTOR': _NEWREPLAYSESSION, '__module__': 'tensorflow.core.protobuf.replay_log_pb2'})
_sym_db.RegisterMessage(NewReplaySession)
ReplayOp = _reflection.GeneratedProtocolMessageType('ReplayOp', (_message.Message,), {'DESCRIPTOR': _REPLAYOP, '__module__': 'tensorflow.core.protobuf.replay_log_pb2'})
_sym_db.RegisterMessage(ReplayOp)
DESCRIPTOR._options = None
